@@ -361,7 +361,9 @@ class PipelineDeployStackAction(
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PipelineDeployStackAction.add_to_deployment_role_policy)
+            def stub(statement: aws_cdk.aws_iam.PolicyStatement) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument statement", value=statement, expected_type=type_hints["statement"])
         return typing.cast(None, jsii.invoke(self, "addToDeploymentRolePolicy", [statement]))
 
@@ -384,7 +386,15 @@ class PipelineDeployStackAction(
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PipelineDeployStackAction.bind)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                stage: aws_cdk.aws_codepipeline.IStage,
+                *,
+                bucket: aws_cdk.aws_s3.IBucket,
+                role: aws_cdk.aws_iam.IRole,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument stage", value=stage, expected_type=type_hints["stage"])
         options = aws_cdk.aws_codepipeline.ActionBindOptions(bucket=bucket, role=role)
@@ -420,7 +430,20 @@ class PipelineDeployStackAction(
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PipelineDeployStackAction.on_state_change)
+            def stub(
+                name: builtins.str,
+                target: typing.Optional[aws_cdk.aws_events.IRuleTarget] = None,
+                *,
+                description: typing.Optional[builtins.str] = None,
+                enabled: typing.Optional[builtins.bool] = None,
+                event_bus: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
+                event_pattern: typing.Optional[typing.Union[aws_cdk.aws_events.EventPattern, typing.Dict[str, typing.Any]]] = None,
+                rule_name: typing.Optional[builtins.str] = None,
+                schedule: typing.Optional[aws_cdk.aws_events.Schedule] = None,
+                targets: typing.Optional[typing.Sequence[aws_cdk.aws_events.IRuleTarget]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         options = aws_cdk.aws_events.RuleProps(
@@ -591,7 +614,21 @@ class PipelineDeployStackActionProps:
             ))
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PipelineDeployStackActionProps.__init__)
+            def stub(
+                *,
+                admin_permissions: builtins.bool,
+                input: aws_cdk.aws_codepipeline.Artifact,
+                stack: aws_cdk.core.Stack,
+                capabilities: typing.Optional[typing.Sequence[aws_cdk.aws_cloudformation.CloudFormationCapabilities]] = None,
+                change_set_name: typing.Optional[builtins.str] = None,
+                create_change_set_action_name: typing.Optional[builtins.str] = None,
+                create_change_set_run_order: typing.Optional[jsii.Number] = None,
+                execute_change_set_action_name: typing.Optional[builtins.str] = None,
+                execute_change_set_run_order: typing.Optional[jsii.Number] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument admin_permissions", value=admin_permissions, expected_type=type_hints["admin_permissions"])
             check_type(argname="argument input", value=input, expected_type=type_hints["input"])
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
